#! /usr/bin/env python3
# -*- coding: utf-8 -*-
import shutil
import configparser
import codecs

#=====================================================================
#
#=====================================================================
class MyConfigParser(configparser.ConfigParser):
    def __init__(self):
        super().__init__()

    def optionxform(self, option):
        """
        ConfigParser オプション文字列 大文字変換
        """

        return option.upper()

#=====================================================================
#
#
#
#=====================================================================
class Config(object):
    """
    Configuration Fileパーサ
    """
    #-------------------------
    #
    #-------------------------
    def __init__(self, config_file):
        """
        @param config_file: ConfigParser formatのファイル
        @type config_file: str
        """
        # Parser objects
        self.__cf_parser = MyConfigParser()

        # filename
        self.__conffile = config_file

        # load
        self.load()

    #-------------------------
    #
    #-------------------------
    def load(self):
        """
        Read from file
        """
        self.__cf_parser.read(self.__conffile, encoding='utf-8')

    #-------------------------
    #
    #-------------------------
    def dump(self):
        """
        Dump to 'ConfigParser' format file
        """
        # dump 'ConfigParser' configuration file only
        shutil.copy(self.__conffile, "%s.backup" % self.__conffile)

        fp = codecs.open(self.__conffile, 'w',"utf-8")
        self.__cf_parser.write(fp)
        fp.close()

    #-------------------------
    #
    #-------------------------
    def __split_sect_opt(self, arg_option):
        l = arg_option.split('_')

        if len(l) < 2:
            return (None, None)

        section = l[0]
        option = '_'.join(l[1:])

        return (section, option)

    #-------------------------
    #
    #-------------------------
    def get(self, option):
        """
        値取得

        @param option: キー
        @type option: str

        @return: 値
        @rtype: str
        """

        try:
            (sect, opt) = self.__split_sect_opt(option)
            val = self.__cf_parser.get(sect, opt)
            return val
        except Exception as msg:
            return False

    #-------------------------
    #
    #-------------------------
    def getint(self, option):
        """
        値取得 (整数で)

        @param option: キー
        @type option: str

        @return: 値
        @rtype: int
        """

        return int(self.get(option))

    #-------------------------
    #
    #-------------------------
    def getfloat(self, option):
        """
        値取得 (浮動小数で)

        @param option: キー
        @type option: str

        @return: 値
        @rtype: float
        """

        return float(self.get(option))

    #-------------------------
    #
    #-------------------------
    def getboolean(self, option):
        """
        値取得 (真偽値で)

        @param option: キー
        @type option: str

        @return: 値
        @rtype: bool
        """

        val = self.get(option)

        try:
            ret = bool(int(val))
        except:
            ret = bool(val)

        return ret

    #-------------------------
    #
    #-------------------------
    def set(self, option, val):
        """
        値設定

        @param option: キー
        @param val: 値

        @type option: str
        @type val: obj

        @return: 成否
        @rtype: bool
        """
        (sect, opt) = self.__split_sect_opt(option)
        self.__cf_parser.set(sect, opt, str(val))
        return True

    #-------------------------
    #
    #-------------------------
    def items(self):
        items = []

        for sect in self.__cf_parser.sections():
            tmp = self.__cf_parser.items(sect)

            for entry in tmp:
                items.append(("%s_%s" % (sect, entry[0]), entry[1]))

        return items


class ConfigOption(object):
    def __init__(self, config_file):

        self.__conffile = config_file
        self.__options = {}
    #-------------------------
    #
    #-------------------------
    def _read(self):
        config = open(self.__conffile, "r")
        for line in config:
            if line.startswith('#') or line.startswith('\n'):
                pass
            else:
                sline = line.strip('\n').split('=')
                if len(sline) > 1:
                    self.__options[sline[0]] = sline[1]

    #-------------------------
    #
    #-------------------------
    def get(self, option): 
        self._read()
        option  = option.upper()
        for option in self.__options:
            return self.__options[option]
        else:
            return False

    #-------------------------
    #
    #-------------------------
    def set(self, option, val):
        self._read()
        option  = option.upper()
        self.__options[option] = val
        config = open(self.__conffile, "w")
        for item in  self.__options.items():
            config.write(item[0]+'='+item[1]+'\n')
        config.close()
